@@ -32,6 +32,77 @@ static GHashTable *ghash_handler = NULL, *ghash_path = NULL;
 
 
 #if defined (G_OS_WIN32) || defined (W32CODECDIR)
+/*static guint32
+icm_handler_tolower (const guint32 key)
+{
+  gint i;
+  guint32 a = 0;
+
+  for (i = 24; i >= 0; i -= 8)
+    {
+      a <<= 8;
+      a |= (guchar)g_ascii_tolower ((gchar)(key >> i));
+    }
+  return a;
+}*/
+
+
+static guint32
+icm_handler_toupper (const guint32 key)
+{
+  gint i;
+  guint32 a = 0;
+
+  for (i = 24; i >= 0; i -= 8)
+    {
+      a <<= 8;
+      a |= (guchar)g_ascii_toupper ((gchar)(key >> i));
+    }
+  return a;
+}
+
+
+static guint
+icm_hash_handler (gconstpointer key)
+{
+  return icm_handler_toupper ((const guint32)key);
+}
+
+
+static gboolean
+icm_equal_handler (gconstpointer a,
+                   gconstpointer b)
+{
+  return icm_handler_toupper ((const guint32)a)
+                                    == icm_handler_toupper ((const guint32)b);
+}
+
+
+static guint
+icm_hash_path (gconstpointer key)
+{
+  const gchar *p;
+  guint h = 0;
+
+  for (p = key; *p != '\0'; p++)
+# ifdef G_OS_WIN32
+    h = (h << 5) - h + g_ascii_tolower (*p);
+# else /* not G_OS_WIN32 */
+    h = (h << 5) - h + *p;
+# endif /* not G_OS_WIN32 */
+
+  return h;
+}
+
+
+static gboolean
+icm_equal_path (gconstpointer a,
+                gconstpointer b)
+{
+  return g_strfilecmp (a, b) == 0;
+}
+
+
 static void
 icm_init_callback (gpointer key,
                    gpointer value,
@@ -111,7 +182,7 @@ icm_init (void)
 
   if (ghash_handler || ghash_path)
     return FALSE;
-  ghash = g_hash_table_new (NULL, g_direct_equal);
+  ghash = g_hash_table_new (NULL, NULL);
 #ifdef G_OS_WIN32
   if (RegOpenKeyEx (HKEY_LOCAL_MACHINE,
         _T("Software\\Microsoft\\Windows NT\\CurrentVersion\\Drivers32"), 0,
@@ -142,10 +213,6 @@ icm_init (void)
       }
 #endif /* G_OS_WIN32 */
 #ifdef W32CODECDIR
-
-  if (ghash_handler || ghash_path)
-    return FALSE;
-  ghash = g_hash_table_new (NULL, g_direct_equal);
   /* ja:設定 */
   profile = profile_open (NULL);
   if (profile)
@@ -204,8 +271,8 @@ icm_init (void)
     }
 #endif /* W32CODECDIR */
 #if defined (G_OS_WIN32) || defined (W32CODECDIR)
-  ghash_handler = g_hash_table_new (NULL, g_direct_equal);
-  ghash_path = g_hash_table_new (g_str_hash, g_str_equal);
+  ghash_handler = g_hash_table_new (icm_hash_handler, icm_equal_handler);
+  ghash_path = g_hash_table_new (icm_hash_path, icm_equal_path);
   g_hash_table_foreach (ghash, icm_init_callback, ghash);
   g_hash_table_destroy (ghash);
 #endif /* defined (G_OS_WIN32) || defined (W32CODECDIR) */
@@ -230,6 +297,7 @@ icm_exit_callback (gpointer key,
       IcmDriver *icm_driver;
 
       icm_driver = orig_value;
+      icm_driver->DriverProc (0, icm_driver->hLib, DRV_DISABLE, 0, 0);
       icm_driver->DriverProc (0, icm_driver->hLib, DRV_FREE, 0, 0);
 #ifdef G_OS_WIN32
       FreeLibrary (icm_driver->hLib);
