@@ -24,8 +24,6 @@
 #include "common.h"
 #include "pe.h"
 
-#include <gmodule.h>
-
 
 #ifdef __cplusplus
 extern "C" {
@@ -55,11 +53,6 @@ struct _pe_image {
 	GHashTable *export;
 	GHashTable *resource;
 	guint8 *image;
-	guint  codec_type;
-#if defined(USE_CODEC)
-	/* for codec(not used from PE) */
-	GModule *module;
-#endif /* deined(USE_CODEC) */
 	/* methods */
 	gboolean (*load)(PE_image *,const gchar *,const gboolean);
 	gpointer (*resolve)(PE_image *,const gchar *);
@@ -76,7 +69,6 @@ struct _pe_image {
 extern SystemDll system_dll[];
 
 
-gboolean isPE(const gchar *file);
 gboolean module_register(const gchar *,PE_image *pe);
 gboolean module_deregister(const gchar *);
 PE_image *module_lookup(const gchar *);
