@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,13 +23,33 @@
 #include "vmaid.h"
 
 
-typedef struct JumpDialog_Tag {
-	gint frame,max;
-	guint32 rate,scale;
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
+typedef struct JumpDialog_Tag
+{
+  gint frame, max;
+  guint32 rate, scale;
 } JumpDialog;
 
 
-gboolean jump_dialog(JumpDialog *jmp);
+/******************************************************************************
+*                                                                             *
+* ja:ジャンプダイアログ関数群                                                 *
+*                                                                             *
+******************************************************************************/
+/*  ja:ジャンプダイアログ表示
+    jmp,ジャンプ構造体
+    RET.TRUE:OK,FALSE:Cancel                                                */
+gboolean
+jump_dialog (JumpDialog *jmp);
+
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
 
 
 #endif
