@@ -807,7 +807,8 @@ signal_scroll (GtkWidget      *widget,
   top = vmaid->top;
   sx = MAX ((widget->allocation.width - 4) / vmaid->width - 2, 1);
   max = get_max_frame (vmaid, -1) + 1;
-  vmaid->top += event->direction == GDK_SCROLL_LEFT ? -4 : 4;
+  vmaid->top += event->direction == GDK_SCROLL_UP
+                            || event->direction == GDK_SCROLL_LEFT ? -4 : 4;
   if (vmaid->top < 0)
     vmaid->top = 0;
   else if (vmaid->top>max - sx)
